# frozen_string_literal: true

module Researchable
  module PdfRenderer
    require 'tempfile'
    require 'yaml'
    class GetPdf < Endpoint
      string :template
      hash :report_data, strip: false

      def execute
        template_file = convert_to_file('template.md', template)
        report_data_file = convert_to_file('report_data.yml', report_data.to_yaml)

        result = validate_response_for do
          basic_auth_session.post(
            '/render',
            template: template_file,
            report_data: report_data_file
          )
        end
        report_data_file.close
        template_file.close
        result
      end

      private

      def convert_to_file(filename, data)
        data_file = Tempfile.new(filename)
        data_file.write(data)
        data_file.rewind
        data_file
      end
    end
  end
end
